==> koffice-trinity_3.5.13.2.orig.tar.xz: koffice-trinity-3.5.13.2/lib/kross/api/eventscript.cpp <==
/***************************************************************************
 * eventscript.cpp
 * This file is part of the KDE project
 * copyright (C)2004-2005 by Sebastian Sauer (mail@dipe.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * You should have received a copy of the GNU Library General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 ***************************************************************************/

#include "eventscript.h"
//#include "object.h"
//#include "variant.h"
//#include "../main/scriptcontainer.h"

using namespace Kross::Api;

EventScript::EventScript(const TQString& name)
    : Event<EventScript>(name)
{
}

EventScript::~EventScript()
{
}

const TQString EventScript::getClassName() const
{
    return "Kross::Api::EventScript";
}

Object::Ptr EventScript::call(const TQString& name, KSharedPtr<List> arguments)
{
    krossdebug( TQString("EventScript::call() name=%1 arguments=%2").arg(name).arg(arguments->toString()) );
    //TODO
    return 0;
}

==> koffice-trinity-14.1.4.tar.xz: koffice-trinity-14.1.4/lib/kross/api/eventscript.cpp <==
/***************************************************************************
 * eventscript.cpp
 * This file is part of the KDE project
 * copyright (C)2004-2005 by Sebastian Sauer (mail@dipe.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * You should have received a copy of the GNU Library General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 ***************************************************************************/

#include "eventscript.h"
//#include "object.h"
//#include "variant.h"
//#include "../main/scriptcontainer.h"

using namespace Kross::Api;

EventScript::EventScript(const TQString& name)
    : Event<EventScript>(name)
{
}

EventScript::~EventScript()
{
}

const TQString EventScript::getClassName() const
{
    return "Kross::Api::EventScript";
}

Object::Ptr EventScript::call(const TQString& name, TDESharedPtr<List> arguments)
{
    krossdebug( TQString("EventScript::call() name=%1 arguments=%2").arg(name).arg(arguments->toString()) );
    //TODO
    return 0;
}
